==> owncloud-10.0.3.tgz: owncloud/apps/files_sharing/l10n/nn_NO.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with you" : "Delt med deg",
    "Shared with others" : "Delt med andre",
    "Shared by link" : "Delt med lenkje",
    "Uploading..." : "Lastar opp …",
    "Nothing shared with you yet" : "Ingenting delt med deg enno",
    "Files and folders others share with you will show up here" : "Filer og mapper som andre deler med deg visast her",
    "Nothing shared yet" : "Ingenting delt enno",
    "Files and folders you share will show up here" : "Filer og mapper som du deler visast her",
    "No shared links" : "Ingen delte lenkjer",
    "Files and folders you share by link will show up here" : "Filer og mapper som du deler med lenkjer visast her",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Vil du leggje til ekstern deling  {name} frå {owner}@{remote}?",
    "Remote share" : "Eksternt delt mappe",
    "Remote share password" : "Passord for eksternt delt mappe",
    "Cancel" : "Avbryt",
    "Add remote share" : "Legg til eksternt delt mappe",
    "You can upload into this folder" : "Du kan lste opp til denne mappa",
    "Invalid ownCloud url" : "Ugyldig ownClud url",
    "Share" : "Del",
    "No expiration date set" : "Ingen dato for utløp er sett",
    "Shared by" : "Delt av",
    "Sharing" : "Deling",
    "A file or folder has been <strong>shared</strong>" : "Ei fil eller ei mappe har blitt <strong>delt</strong>",
    "You shared %1$s with %2$s" : "Du delte %1$s med %2$s",
    "You shared %1$s with group %2$s" : "Du delte %1$s med gruppa %2$s",
    "You shared %1$s via link" : "Du delte %1$s via ei lenkje",
    "%2$s shared %1$s with you" : "%2$s delte %1$s med deg",
    "Shares" : "Delingar",
    "The password is wrong. Try again." : "Passordet er gale. Prøv igjen.",
    "Password" : "Passord",
    "Name" : "Namn",
    "Expiration date" : "Utløpsdato",
    "Sorry, this link doesn’t seem to work anymore." : "Orsak, denne lenkja fungerer visst ikkje lenger.",
    "Reasons might be:" : "Moglege grunnar:",
    "the item was removed" : "fila/mappa er fjerna",
    "the link expired" : "lenkja har gått ut på dato",
    "sharing is disabled" : "deling er slått av",
    "For more info, please ask the person who sent this link." : "Spør den som sende deg lenkje om du vil ha meir informasjon.",
    "Download" : "Last ned"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.0.10.tgz: owncloud/apps/files_sharing/l10n/nn_NO.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with you" : "Delt med deg",
    "Shared with others" : "Delt med andre",
    "Shared by link" : "Delt med lenkje",
    "Uploading..." : "Lastar opp …",
    "Nothing shared with you yet" : "Ingenting delt med deg enno",
    "Files and folders others share with you will show up here" : "Filer og mapper som andre deler med deg visast her",
    "Nothing shared yet" : "Ingenting delt enno",
    "Files and folders you share will show up here" : "Filer og mapper som du deler visast her",
    "No shared links" : "Ingen delte lenkjer",
    "Files and folders you share by link will show up here" : "Filer og mapper som du deler med lenkjer visast her",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Vil du leggje til ekstern deling  {name} frå {owner}@{remote}?",
    "Remote share" : "Eksternt delt mappe",
    "Remote share password" : "Passord for eksternt delt mappe",
    "Cancel" : "Avbryt",
    "Add remote share" : "Legg til eksternt delt mappe",
    "You can upload into this folder" : "Du kan lste opp til denne mappa",
    "Invalid ownCloud url" : "Ugyldig ownClud url",
    "Share" : "Del",
    "No expiration date set" : "Ingen dato for utløp er sett",
    "Shared by" : "Delt av",
    "Sharing" : "Deling",
    "A file or folder has been <strong>shared</strong>" : "Ei fil eller ei mappe har blitt <strong>delt</strong>",
    "You shared %1$s with %2$s" : "Du delte %1$s med %2$s",
    "You shared %1$s with group %2$s" : "Du delte %1$s med gruppa %2$s",
    "You shared %1$s via link" : "Du delte %1$s via ei lenkje",
    "%2$s shared %1$s with you" : "%2$s delte %1$s med deg",
    "Shares" : "Delingar",
    "The password is wrong. Try again." : "Passordet er gale. Prøv igjen.",
    "Password" : "Passord",
    "Name" : "Namn",
    "Expiration date" : "Utløpsdato",
    "Sorry, this link doesn’t seem to work anymore." : "Orsak, denne lenkja fungerer visst ikkje lenger.",
    "Reasons might be:" : "Moglege grunnar:",
    "the item was removed" : "fila/mappa er fjerna",
    "the link expired" : "lenkja har gått ut på dato",
    "sharing is disabled" : "deling er slått av",
    "For more info, please ask the person who sent this link." : "Spør den som sende deg lenkje om du vil ha meir informasjon.",
    "Download" : "Last ned",
    "No entries found in this folder" : "Ingen oppføring i dette området",
    "Pending" : "Under vegs",
    "Accept" : "Godtake",
    "Decline" : "Avslå",
    "Declined" : "Avvist"
},
"nplurals=2; plural=(n != 1);");
